-- PLUGINS - PACKER

local fn = vim.fn
local install_path = fn.stdpath('data')..'/site/pack/packer/start/packer.nvim'
if fn.empty(fn.glob(install_path)) > 0 then
  packer_bootstrap = fn.system({'git', 'clone', '--depth', '1', 'https://github.com/wbthomason/packer.nvim', install_path})
  vim.cmd [[packadd packer.nvim]]
end

return require('packer').startup(function(use)
  -- Packer can manage itself
  use 'wbthomason/packer.nvim'

  -- Nvim LSP
  use 'neovim/nvim-lspconfig'

  -- Tree-sitter
  use {
    'nvim-treesitter/nvim-treesitter',
    run = function() require('nvim-treesitter.install').update({ with_sync = true }) end,
  }

  -- Snippets
  use 'L3MON4D3/LuaSnip'
  use 'rafamadriz/friendly-snippets'

  -- Completion
  use 'hrsh7th/nvim-cmp'
  use 'hrsh7th/cmp-buffer'
  use 'hrsh7th/cmp-path'
  use 'hrsh7th/cmp-nvim-lua'
  use 'hrsh7th/cmp-nvim-lsp'
  use 'saadparwaiz1/cmp_luasnip'

  -- Telescope
  use {
    'nvim-telescope/telescope.nvim', branch = '0.1.x',
    requires = { {'nvim-lua/plenary.nvim'} }
  }
  use {'nvim-telescope/telescope-fzf-native.nvim', run = 'make' }

  -- Color schemes
  use 'morhetz/gruvbox'
  use 'sjl/badwolf'

  -- Auto close parens and such
  use 'Townk/vim-autoclose'

  -- Surround
  use 'tpope/vim-surround'

  -- NERDTree
  use 'preservim/nerdtree'
  use 'Xuyuanp/nerdtree-git-plugin' -- A NERDTree plugin showing git status

  -- VimTeX
  use 'lervag/vimtex'

  --  Display thin vertical lines at each indentation level
  use 'Yggdroot/indentLine'

  --  Ansible syntax highlighting
  use 'pearofducks/ansible-vim'

  -- Automatically set up your configuration after cloning packer.nvim
  -- Put this at the end after all plugins
  if packer_bootstrap then
    require('packer').sync()
  end
end)
